# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'medved/ui//ui_wmedeval.ui'
#
# Created by: PyQt5 UI code generator 5.8.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MEDeval(object):
    def setupUi(self, MEDeval):
        MEDeval.setObjectName("MEDeval")
        MEDeval.resize(900, 674)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/medeval"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MEDeval.setWindowIcon(icon)
        MEDeval.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.centralwidget = QtWidgets.QWidget(MEDeval)
        self.centralwidget.setObjectName("centralwidget")
        MEDeval.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MEDeval)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 900, 49))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MEDeval.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MEDeval)
        self.statusbar.setObjectName("statusbar")
        MEDeval.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(MEDeval)
        self.toolBar.setObjectName("toolBar")
        MEDeval.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.dock = QtWidgets.QDockWidget(MEDeval)
        self.dock.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.dock.setObjectName("dock")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.dock.setWidget(self.dockWidgetContents)
        MEDeval.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dock)
        self.actionOpenDir = QtWidgets.QAction(MEDeval)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/folder"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpenDir.setIcon(icon1)
        self.actionOpenDir.setObjectName("actionOpenDir")
        self.actionReal = QtWidgets.QAction(MEDeval)
        self.actionReal.setCheckable(True)
        self.actionReal.setChecked(True)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/re"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionReal.setIcon(icon2)
        self.actionReal.setObjectName("actionReal")
        self.actionImaginary = QtWidgets.QAction(MEDeval)
        self.actionImaginary.setCheckable(True)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/im"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionImaginary.setIcon(icon3)
        self.actionImaginary.setObjectName("actionImaginary")
        self.actionAmplitude = QtWidgets.QAction(MEDeval)
        self.actionAmplitude.setCheckable(True)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/ampl"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAmplitude.setIcon(icon4)
        self.actionAmplitude.setObjectName("actionAmplitude")
        self.actionPhase = QtWidgets.QAction(MEDeval)
        self.actionPhase.setCheckable(True)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/phi"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPhase.setIcon(icon5)
        self.actionPhase.setObjectName("actionPhase")
        self.action2Theta = QtWidgets.QAction(MEDeval)
        self.action2Theta.setCheckable(True)
        self.action2Theta.setChecked(True)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/theta"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2Theta.setIcon(icon6)
        self.action2Theta.setObjectName("action2Theta")
        self.actionD = QtWidgets.QAction(MEDeval)
        self.actionD.setCheckable(True)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/d"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionD.setIcon(icon7)
        self.actionD.setObjectName("actionD")
        self.actionD2 = QtWidgets.QAction(MEDeval)
        self.actionD2.setCheckable(True)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/d2"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionD2.setIcon(icon8)
        self.actionD2.setObjectName("actionD2")
        self.actionAbout = QtWidgets.QAction(MEDeval)
        self.actionAbout.setObjectName("actionAbout")
        self.actionQuit = QtWidgets.QAction(MEDeval)
        self.actionQuit.setObjectName("actionQuit")
        self.actionOpenFiles = QtWidgets.QAction(MEDeval)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/file"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpenFiles.setIcon(icon9)
        self.actionOpenFiles.setObjectName("actionOpenFiles")
        self.actionListDock = QtWidgets.QAction(MEDeval)
        self.actionListDock.setCheckable(True)
        self.actionListDock.setChecked(False)
        self.actionListDock.setObjectName("actionListDock")
        self.actionClean = QtWidgets.QAction(MEDeval)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/clean"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionClean.setIcon(icon10)
        self.actionClean.setObjectName("actionClean")
        self.actionCheckUpdates = QtWidgets.QAction(MEDeval)
        self.actionCheckUpdates.setObjectName("actionCheckUpdates")
        self.menu_File.addAction(self.actionOpenFiles)
        self.menu_File.addAction(self.actionOpenDir)
        self.menu_File.addAction(self.actionClean)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.actionQuit)
        self.menuView.addAction(self.actionListDock)
        self.menuView.addSeparator()
        self.menuView.addAction(self.actionReal)
        self.menuView.addAction(self.actionImaginary)
        self.menuView.addAction(self.actionAmplitude)
        self.menuView.addAction(self.actionPhase)
        self.menuView.addSeparator()
        self.menuView.addAction(self.action2Theta)
        self.menuView.addAction(self.actionD)
        self.menuView.addAction(self.actionD2)
        self.menuHelp.addAction(self.actionCheckUpdates)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionOpenFiles)
        self.toolBar.addAction(self.actionOpenDir)
        self.toolBar.addAction(self.actionClean)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionReal)
        self.toolBar.addAction(self.actionImaginary)
        self.toolBar.addAction(self.actionAmplitude)
        self.toolBar.addAction(self.actionPhase)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action2Theta)
        self.toolBar.addAction(self.actionD)
        self.toolBar.addAction(self.actionD2)

        self.retranslateUi(MEDeval)
        QtCore.QMetaObject.connectSlotsByName(MEDeval)

    def retranslateUi(self, MEDeval):
        _translate = QtCore.QCoreApplication.translate
        MEDeval.setWindowTitle(_translate("MEDeval", "MEDved"))
        self.menu_File.setTitle(_translate("MEDeval", "&File"))
        self.menuView.setTitle(_translate("MEDeval", "&View"))
        self.menuHelp.setTitle(_translate("MEDeval", "&Help"))
        self.toolBar.setWindowTitle(_translate("MEDeval", "toolBar"))
        self.actionOpenDir.setText(_translate("MEDeval", "&Open directory..."))
        self.actionOpenDir.setShortcut(_translate("MEDeval", "Ctrl+F"))
        self.actionReal.setText(_translate("MEDeval", "&Real part"))
        self.actionReal.setToolTip(_translate("MEDeval", "Show real part"))
        self.actionReal.setShortcut(_translate("MEDeval", "Ctrl+R"))
        self.actionImaginary.setText(_translate("MEDeval", "&Imaginary part"))
        self.actionImaginary.setToolTip(_translate("MEDeval", "Show imaginary part"))
        self.actionImaginary.setShortcut(_translate("MEDeval", "Ctrl+I"))
        self.actionAmplitude.setText(_translate("MEDeval", "&Amplitute"))
        self.actionAmplitude.setToolTip(_translate("MEDeval", "Show amplitude"))
        self.actionAmplitude.setShortcut(_translate("MEDeval", "Ctrl+A"))
        self.actionPhase.setText(_translate("MEDeval", "&Phase"))
        self.actionPhase.setToolTip(_translate("MEDeval", "Show phase"))
        self.actionPhase.setShortcut(_translate("MEDeval", "Ctrl+P"))
        self.action2Theta.setText(_translate("MEDeval", "&2Theta"))
        self.action2Theta.setShortcut(_translate("MEDeval", "Ctrl+T"))
        self.actionD.setText(_translate("MEDeval", "&d"))
        self.actionD.setShortcut(_translate("MEDeval", "Ctrl+D"))
        self.actionD2.setText(_translate("MEDeval", "d2"))
        self.actionD2.setShortcut(_translate("MEDeval", "Ctrl+2"))
        self.actionAbout.setText(_translate("MEDeval", "&About..."))
        self.actionQuit.setText(_translate("MEDeval", "&Quit"))
        self.actionQuit.setShortcut(_translate("MEDeval", "Ctrl+Q"))
        self.actionOpenFiles.setText(_translate("MEDeval", "Open &files..."))
        self.actionOpenFiles.setShortcut(_translate("MEDeval", "Ctrl+O"))
        self.actionListDock.setText(_translate("MEDeval", "&List dock"))
        self.actionListDock.setShortcut(_translate("MEDeval", "Ctrl+L"))
        self.actionClean.setText(_translate("MEDeval", "&Clean"))
        self.actionClean.setShortcut(_translate("MEDeval", "Ctrl+Z"))
        self.actionCheckUpdates.setText(_translate("MEDeval", "Check updates..."))

from . import resources_rc
